@@ -5,7 +5,7 @@ from netbox_storage.api.views import (
     DriveViewSet,
     FilesystemViewSet,
     PartitionViewSet,
-    LinuxVolumeViewSet,
+    MountedVolumeViewSet,
 )
 
 router = NetBoxRouter()
@@ -14,6 +14,6 @@ router.APIRootView = NetboxStorageRootView
 router.register("drive", DriveViewSet)
 router.register("filesystem", FilesystemViewSet)
 router.register("partition", PartitionViewSet)
-router.register("linuxvolume", LinuxVolumeViewSet)
+router.register("mountedvolume", MountedVolumeViewSet)
 
 urlpatterns = router.urls
