@@ -2,19 +2,17 @@ from django.db.models import Q
 
 from netbox.filtersets import NetBoxModelFilterSet
 
-from netbox_storage.models import LinuxVolume
+from netbox_storage.models import MountedVolume
 
 
-class LinuxVolumeFilter(NetBoxModelFilterSet):
-    """Filter capabilities for LinuxVolume instances."""
+class MountedVolumeFilter(NetBoxModelFilterSet):
 
     class Meta:
-        model = LinuxVolume
+        model = MountedVolume
         fields = [
             "size",
             "path",
             "description",
-            "storage_configuration"
         ]
 
     def search(self, queryset, name, value):
