@@ -341,18 +341,16 @@ class PartitionTemplateForm(NetBoxModelForm):
         ]
 
     def save(self, *args, **kwargs):
-        drive = Drive.objects.filter(id=1)
-        partition = Partition.objects.create(drive=drive, )
-        self.instance.drive = drive
-        template_configuration = super().save(*args, **kwargs)
+        print(f"{self.cleaned_data['drive']}")
+        # drive = Drive.objects.create()
 
-        print(f"{self.cleaned_data['size']}")
+        # linux_device = LinuxDevice.objects.create(device='/dev/sda1', type='efi')
+        # partition = Partition.objects.create(drive=drive, device=linux_device, size=self.cleaned_data['size'], type='vfat')
 
-        print("Instances")
-        print(drive)
-        print(template_configuration)
+        # template_configuration = super().save(*args, **kwargs)
 
-        return template_configuration
+        # print(f"{self.cleaned_data['size']}")
+        return None
 
 
 class VolumeSimpleForm(NetBoxModelForm):
