@@ -27,14 +27,13 @@ class Drive(NetBoxModel):
 
     prerequisite_models = (
         'virtualization.Cluster',
-        'virtualization.VirtualMachine',
     )
 
     class Meta:
         ordering = ["size"]
 
     def __str__(self):
-        return f"VM: ({self.identifier}-{self.size}GB-{self.cluster})"
+        return f"{self.identifier}-{self.size}MB-{self.cluster})"
 
     def get_absolute_url(self):
         return reverse("plugins:netbox_storage:drive", kwargs={"pk": self.pk})
@@ -82,9 +81,6 @@ class LinuxDevice(NetBoxModel):
 
     clone_fields = ["device", "type", "description"]
 
-    class Meta:
-        ordering = ["size"]
-
     def __str__(self):
         return f'{self.device}'
 
