@@ -62,8 +62,8 @@ class LogicalVolumeIndex(SearchIndex):
 
 
 @register_search
-class LinuxVolumeIndex(SearchIndex):
-    model = models.LinuxVolume
+class MountedVolumeIndex(SearchIndex):
+    model = models.MountedVolume
     fields = (
         ('size', 100),
         ('path', 100),
